@@ -8,12 +8,16 @@ module Faker
       end
 
       def author
-        fetch('book.author')
+        parse('book.author')
       end
 
       def publisher
         fetch('book.publisher')
       end
+
+      def genre
+        fetch('book.genre')
+      end
     end
   end
 end
